@@ -19,6 +19,7 @@
 #include <string.h>
 
 #include "alloc.h"
+#include "atoi/str2i.h"
 #include "string/sprintf.h"
 
 
@@ -107,9 +108,9 @@ subordinate_parse(const char *line)
 	if (i != SUBID_NFIELDS || *fields[0] == '\0' || *fields[1] == '\0' || *fields[2] == '\0')
 		return NULL;
 	range.owner = fields[0];
-	if (getulong(fields[1], &range.start) == -1)
+	if (str2ul(&range.start, fields[1]) == -1)
 		return NULL;
-	if (getulong(fields[2], &range.count) == -1)
+	if (str2ul(&range.count, fields[2]) == -1)
 		return NULL;
 
 	return &range;
